@@ -326,7 +326,9 @@ class measurement {
     {
         return {value_ - other.value_as(units_), units_};
     }
-
+    // add unary operators
+    constexpr measurement operator+() const { return {value_, units_}; }
+    constexpr measurement operator-() const { return {-value_, units_}; }
     // double multiplier
     friend constexpr inline measurement
         operator*(double val, const measurement& meas)
@@ -548,7 +550,9 @@ class fixed_measurement {
     {
         return {value_ - val, units_};
     }
-
+    // add unary operators
+    constexpr fixed_measurement operator+() const { return {value_, units_}; }
+    constexpr fixed_measurement operator-() const { return {-value_, units_}; }
     /// take the measurement to some power
     constexpr friend fixed_measurement
         pow(const fixed_measurement& meas, int power)
@@ -738,17 +742,14 @@ class uncertain_measurement {
         float val,
         float uncertainty_val,
         const unit& base) noexcept :
-        value_(val),
-        uncertainty_(uncertainty_val), units_(base)
+        value_(val), uncertainty_(uncertainty_val), units_(base)
     {
     }
     /// construct from a single precision value, and unit assume uncertainty is
     /// 0
     explicit constexpr uncertain_measurement(
         float val,
-        const unit& base) noexcept :
-        value_(val),
-        units_(base)
+        const unit& base) noexcept : value_(val), units_(base)
     {
     }
 
@@ -757,16 +758,15 @@ class uncertain_measurement {
     explicit constexpr uncertain_measurement(
         double val,
         const unit& base) noexcept :
-        value_(static_cast<float>(val)),
-        units_(base)
+        value_(static_cast<float>(val)), units_(base)
     {
     }
     /// construct from a regular measurement and uncertainty value
     explicit constexpr uncertain_measurement(
         const measurement& val,
         float uncertainty_val) noexcept :
-        value_(static_cast<float>(val.value())),
-        uncertainty_(uncertainty_val), units_(val.units())
+        value_(static_cast<float>(val.value())), uncertainty_(uncertainty_val),
+        units_(val.units())
     {
     }
     /// construct from a regular measurement and an uncertainty measurement
@@ -980,7 +980,15 @@ class uncertain_measurement {
         auto cval = static_cast<float>(other.value_as(units_));
         return {value_ - cval, uncertainty_, units_};
     }
-
+    // add unary operators
+    constexpr uncertain_measurement operator+() const
+    {
+        return {value_, uncertainty_, units_};
+    }
+    constexpr uncertain_measurement operator-() const
+    {
+        return {-value_, uncertainty_, units_};
+    }
     /// take the measurement to some power
     friend UNITS_CPP14_CONSTEXPR_METHOD uncertain_measurement
         pow(const uncertain_measurement& meas, int power)
@@ -1268,6 +1276,12 @@ class precise_measurement {
     {
         return {value_ - other.value_as(units_), units_};
     }
+    // add unary operators
+    constexpr precise_measurement operator+() const { return {value_, units_}; }
+    constexpr precise_measurement operator-() const
+    {
+        return {-value_, units_};
+    }
 
     /// take the measurement to some power
     constexpr friend precise_measurement
@@ -1399,22 +1413,19 @@ class fixed_precise_measurement {
 
     explicit constexpr fixed_precise_measurement(
         const precise_measurement& val) :
-        value_(val.value()),
-        units_(val.units())
+        value_(val.value()), units_(val.units())
     {
     }
 
     constexpr fixed_precise_measurement(
         const fixed_precise_measurement& val) noexcept :
-        value_(val.value()),
-        units_(val.units())
+        value_(val.value()), units_(val.units())
     {
     }
 
     constexpr fixed_precise_measurement(
         fixed_precise_measurement&& val) noexcept :
-        value_(val.value()),
-        units_(val.units())
+        value_(val.value()), units_(val.units())
     {
     }
 
@@ -1515,7 +1526,15 @@ class fixed_precise_measurement {
     {
         return {value_ - val, units_};
     }
-
+    // add unary operators
+    constexpr fixed_precise_measurement operator+() const
+    {
+        return {value_, units_};
+    }
+    constexpr fixed_precise_measurement operator-() const
+    {
+        return {-value_, units_};
+    }
     fixed_precise_measurement& operator+=(double val)
     {
         value_ += val;
@@ -2278,6 +2297,11 @@ namespace detail {
     UNITS_EXPORT const std::unordered_map<std::string, precise_unit>&
         getUnitStringMap();
     UNITS_EXPORT const std::unordered_map<unit, const char*>& getUnitNameMap();
+
+#ifdef EXTRA_UNIT_STANDARDS
+    // get the raw array for testing the r20 database
+    const void* r20rawData(size_t& array_size);
+#endif
 }  // namespace detail
 #endif
 
